@@ -15,11 +15,8 @@ logging=logger.get_logger(name='mlops_deployment')
 env = config.envs.env
 service_name = config.envs.service_name
 
-
-
 platform_methods = platforms.get_methods()
 
-
 def deploy_model(model_settings, platform_methods=platform_methods):
 
     c = model_settings
@@ -105,5 +102,5 @@ def deploy(project_settings):
 
 if __name__ == '__main__':
     mm.setup()
-    s = config.read_config().project_settings
+    s = config.read_project_settings()
     deploy(s)
\ No newline at end of file
