@@ -1,6 +1,7 @@
 # helpers.py
 import sys
 import os
+from pathlib import Path
 
 from importlib import import_module, resources as importlib_resources
 import shutil
@@ -106,7 +107,7 @@ def run_tests(test_path, path_type='file'):
                 "--quiet", "--color=no", "-W ignore:numpy.ufunc size changed"]
     if path_type == 'module':
         command.append("--pyargs")
-    if isinstance(test_path, str):
+    if isinstance(test_path, str) or isinstance(test_path, Path):
         command.append(test_path)
     elif isinstance(test_path, list):
         command += test_path
